@@ -1,11 +1,11 @@
-__version__ = '0.1.3'
+__version__ = '0.1.4'
 
 print('Scratch Encode/Decode Package By Joecooldoo\nScratchblocks: https://turbowarp.org/585257923/editor')
 
 def split(word):
     return [char for char in word]
 
-class Encode:
+class encode:
   def encode(word): #This is for the custom command "encode"
     letters = ["a","b","c","d","e","f","g","h","i","j","k","l","m","n","o","p","q","r","s","t","u","v","w","x","y","z","1","2","3","4","5","6","7","8","9","0","_","-",".","!","?","@","#","$","%","^","&","*","(",")","+","=","{","}","|","[","]","","'","<",">","?",",",".","/"," ",";","\n",":","❌","✔",'️']
 
@@ -25,7 +25,7 @@ class Encode:
 
     return(output)
 
-class Decode:
+class decode:
   def decode(word):
     letters = ["a","b","c","d","e","f","g","h","i","j","k","l","m","n","o","p","q","r","s","t","u","v","w","x","y","z","1","2","3","4","5","6","7","8","9","0","_","-",".","!","?","@","#","$","%","^","&","*","(",")","+","=","{","}","|","[","]","","'","<",">","?",",",".","/"," ",";","\n",":","❌","✔",'️']
 
